@@ -2,61 +2,59 @@ var info =
 {
 "pages":
 [
-["PCSS_UserGuide\u002FIntroduction.html","Introduction","PowerChute\u2122 Serial Shutdown (PowerChute) provides UPS management, system shutdown, and energy management for devices connected to the UPS, via USB interface.","PCSS_UserGuide\u002Fpairs\u002Fpair1.js"]
-,["PCSS_UserGuide\u002FDeviceModel.html","UPS Device Model","The model name of your UPS displays at the top level of these menu options, e.g. Back-UPS NS 650M1. All of the menu options relate to your UPS.","PCSS_UserGuide\u002Fpairs\u002Fpair1_2.js"]
-,["PCSS_UserGuide\u002FPowerChute.html","PowerChute","Event Configuration","PCSS_UserGuide\u002Fpairs\u002Fpair1_3.js"]
-,["PCSS_UserGuide\u002FShutdown.html","Shutdown","In PowerChute Serial Shutdown, shutdowns can be initiated:","PCSS_UserGuide\u002Fpairs\u002Fpair1_4.js"]
-,["PCSS_UserGuide\u002FDataLog.html","Logging","Event Log","PCSS_UserGuide\u002Fpairs\u002Fpair1_5.js"]
-,["PCSS_UserGuide\u002FEnergy%20Management.html","Energy Management","Energy Management enables you to monitor the energy consumption of equipment attached to your UPS. This includes carbon dioxide consumption and your energy costs.","PCSS_UserGuide\u002Fpairs\u002Fpair1_6.js"]
-,["PCSS_UserGuide\u002FAbout.html","About","The About dialog provides information about the UPS, and the system connected to the UPS.","PCSS_UserGuide\u002Fpairs\u002Fpair1_7.js"]
-,["PCSS_UserGuide\u002FGeneral.08.1.html","General","","PCSS_UserGuide\u002Fpairs\u002Fpair1_8.js"]
-,["PCSS_UserGuide\u002FGeneral.08.2.html","General","PowerChute Configuration File","PCSS_UserGuide\u002Fpairs\u002Fpair2.js"]
-,["PCSS_UserGuide\u002FPreferences.html","Preferences","Customer Experience Improvement Program (CEIP)","PCSS_UserGuide\u002Fpairs\u002Fpair1_9.js"]
-,["PCSS_UserGuide\u002FTroubleshooting.html","Troubleshooting","PowerChute Files ZIP Archive","PCSS_UserGuide\u002Fpairs\u002Fpair1_10.js"]
+["PCSS_UserGuide\u002FBackUPS\u002FIntroduction.html","Introduction","PowerChute\u2122 Serial Shutdown (PowerChute) provides UPS management, system shutdown, and energy management for devices connected to the UPS, via UPS interface. In the case of a UPS critical event, the software performs a graceful system shutdown of connected devices before the UPS battery is exhausted...","PCSS_UserGuide\u002Fpairs\u002Fpair1.js","content-page"]
+,["PCSS_UserGuide\u002FBackUPS\u002FDeviceModel.html","UPS Device Model","The model name of your UPS displays at the top level of these menu options, e.g. Back-UPS NS 650M1. All of the menu options relate to your UPS. UPS Status The UPS Status screen has three sections \u2014 System Status, Power Status, and Battery Status. Each of the sections is collapsible and expandable by...","PCSS_UserGuide\u002Fpairs\u002Fpair1_2.js","content-page"]
+,["PCSS_UserGuide\u002FBackUPS\u002FPowerChute.html","PowerChute","Event Configuration The Event Configuration screen lists the events that can occur and separates them into three categories - critical (severe), warning, and informational. You cannot change an event\u0027s category. By default, the Informational events are hidden, click the + icon beside Informational t...","PCSS_UserGuide\u002Fpairs\u002Fpair1_3.js","content-page"]
+,["PCSS_UserGuide\u002FBackUPS\u002FShutdown.html","Shutdown","In PowerChute Serial Shutdown, shutdowns can be initiated: \u2022 Through an event occurring, see Event Configuration.  Initial Setup This option guides you through a series of screens that enable you to complete your shutdown configuration. The configuration screens are listed below in their display ord...","PCSS_UserGuide\u002Fpairs\u002Fpair1_4.js","content-page"]
+,["PCSS_UserGuide\u002FBackUPS\u002FDataLog.html","Logging","Event Log A PowerChute event can be critical, warning, or informational. An example of a critical event is a low battery, and a warning event could be when power to the UPS has been interrupted. Informational events are everyday occurrences such as the monitoring of your system has started, or a sel...","PCSS_UserGuide\u002Fpairs\u002Fpair1_5.js","content-page"]
+,["PCSS_UserGuide\u002FBackUPS\u002FEnergy%20Management.html","Energy Management","Energy Management enables you to monitor the energy consumption of equipment attached to your UPS. This includes carbon dioxide consumption and your energy costs. Energy Management accesses data on Schneider Electric servers by using the Internet.  Energy Reporting The energy report gives you inform...","PCSS_UserGuide\u002Fpairs\u002Fpair1_6.js","content-page"]
+,["PCSS_UserGuide\u002FBackUPS\u002FAbout.html","About","The About dialog provides information about the UPS, and the system connected to the UPS. UPS Information Parameters Parameter Description UPS Model The model name of the UPS, e.g. Back-UPS NS 650M1. Firmware Revision The revision of the UPS firmware. NOTE: This value does not display for all UPS de...","PCSS_UserGuide\u002Fpairs\u002Fpair1_7.js","content-page"]
+,["PCSS_UserGuide\u002FBackUPS\u002FGeneral.37.1.html","General","","PCSS_UserGuide\u002Fpairs\u002Fpair1_8.js","content-page"]
+,["PCSS_UserGuide\u002FBackUPS\u002FGeneral.37.2.html","General","PowerChute Configuration File PowerChute stores some configuration settings in a file called pcssconfig.ini, located in the Agent directory in the installed PowerChute directory. If the default location was chosen during installation, the pcssconfig.ini file can be found at: C:\u005CProgram Files\u005CAPC\u005CPow...","PCSS_UserGuide\u002Fpairs\u002Fpair2.js","content-page"]
+,["PCSS_UserGuide\u002FBackUPS\u002FPreferences.html","Preferences","Customer Experience Improvement Program (CEIP) PowerChute\u0027s Customer Experience Improvement Program (CEIP) provides us with the information that enables us to improve our product and services, and helps us to advise you on how best to deploy and configure PowerChute. As part of the CEIP, we will col...","PCSS_UserGuide\u002Fpairs\u002Fpair1_9.js","content-page"]
+,["PCSS_UserGuide\u002FBackUPS\u002FTroubleshooting.html","Troubleshooting","PowerChute Files ZIP Archive To help the PowerChute team resolve customer issues, the PowerChute files ZIP archive feature creates a ZIP archive of the necessary PowerChute configuration files for troubleshooting. This feature can be found in the Troubleshooting section in the About dialog. This ZIP...","PCSS_UserGuide\u002Fpairs\u002Fpair1_10.js","content-page"]
 ],
 "words":
 {
 "introduction":[0,1]
-,"powerchute":[0,18,1,2,2,23,3,1,4,2,5,6,6,5,8,26,9,9,10,7]
+,"powerchute":[0,19,1,2,2,26,3,1,4,4,5,6,6,5,8,29,9,9,10,8]
 ,"serial":[0,11,2,5,3,1,4,2,5,1,6,4,8,5,9,1,10,1]
-,"shutdown":[0,13,1,4,2,32,3,31,5,1,6,2,8,2,9,1]
-,"(powerchute)":[0,1]
+,"shutdown":[0,13,1,4,2,75,3,62,4,2,5,1,6,2,8,5,9,1,10,1]
 ,"provides":[0,1,4,1,6,1,9,1]
-,"ups":[0,8,1,69,2,67,3,8,4,9,5,9,6,20]
-,"management":[0,2,1,2,2,1,5,3]
-,"system":[0,4,1,6,2,5,3,4,4,2,5,2,6,5,8,2]
+,"ups":[0,9,1,173,2,67,3,8,4,19,5,9,6,20]
+,"management":[0,2,1,12,2,1,5,3]
+,"system":[0,4,1,16,2,15,3,4,4,2,5,2,6,5,8,2]
 ,"energy":[0,1,4,5,5,28]
 ,"devices":[0,2,1,8,2,5,5,1,6,1]
-,"connected":[0,2,1,3,2,7,4,1,6,7]
+,"connected":[0,2,1,4,2,7,4,1,6,7]
 ,"via":[0,1,2,3]
-,"usb":[0,1]
 ,"interface":[0,5,2,3,8,1]
 ,"case":[0,1,8,1]
-,"critical":[0,1,2,3,4,2]
-,"event":[0,1,1,1,2,34,3,29,4,14]
+,"critical":[0,1,2,14,4,2]
+,"event":[0,1,1,1,2,418,3,59,4,45]
 ,"software":[0,2,8,1,9,1]
 ,"performs":[0,1,1,1]
 ,"graceful":[0,1,2,3]
-,"battery":[0,1,1,40,2,34,3,20,4,5,6,2]
+,"battery":[0,1,1,210,2,124,3,40,4,25,6,2]
 ,"exhausted":[0,1]
 ,"following":[0,1,1,5,2,3,4,2,8,1]
-,"installation":[0,3,1,2,3,1,5,5,6,1,8,8,10,1]
+,"installation":[0,3,1,12,2,1,3,1,5,5,6,1,8,8,10,1]
 ,"configure":[0,1,1,1,2,6,3,1,4,2,9,2]
 ,"using":[0,2,1,3,2,13,4,2,5,1,8,1]
-,"initial":[0,1,3,1]
-,"setup":[0,1,3,1]
+,"initial":[0,1,3,11]
+,"setup":[0,1,3,11]
 ,"wizard":[0,1]
 ,"ensures":[0,1]
 ,"configured":[0,1,2,6,3,3,8,1]
 ,"monitor":[0,1,5,1]
 ,"manage":[0,1]
-,"power":[0,1,1,14,2,19,3,12,4,1]
-,"events":[0,1,2,23,3,4,4,5]
+,"power":[0,1,1,66,2,39,3,52,4,1]
+,"events":[0,1,1,1,2,53,3,4,4,5]
 ,"document":[0,2]
 ,"describes":[0,2]
-,"options":[0,1,1,6,2,2,3,5,4,2]
-,"available":[0,2,2,9,8,2,9,1]
-,"agent":[0,7,1,1,2,3,6,4,8,5,10,1]
+,"options":[0,1,1,6,2,2,3,15,4,2]
+,"available":[0,2,2,19,8,3,9,1]
+,"agent":[0,7,1,1,2,5,4,2,6,4,8,7,10,2]
 ,"user":[0,4,1,1,2,9]
 ,"back-ups":[0,3,1,1,6,1]
 ,"supported":[0,2,1,2,2,3,8,1]
@@ -82,12 +80,12 @@ var info =
 ,"installing":[0,1]
 ,"guide":[0,1]
 ,"security-related":[0,1]
-,"security":[0,1,2,2,8,1]
+,"security":[0,1,2,3,8,1]
 ,"handbook":[0,1,8,1]
 ,"up-to-date":[0,1]
 ,"operating":[0,2,1,1,2,5,3,5,5,1,6,2]
-,"systems":[0,1,8,2,10,1]
-,"jre":[0,1,2,2]
+,"systems":[0,1,8,3,10,1]
+,"jre":[0,1,2,3]
 ,"service":[0,1,2,2,8,6]
 ,"packs":[0,1,1,1]
 ,"processors":[0,1]
@@ -97,7 +95,7 @@ var info =
 ,"processor":[0,1]
 ,"compatibility":[0,1,8,1]
 ,"chart":[0,1,8,1]
-,"log":[0,1,2,3,3,1,4,29,8,1,10,1]
+,"log":[0,1,2,3,3,1,4,139,8,1,10,1]
 ,"access":[0,3,3,1]
 ,"two":[0,1,1,1]
 ,"ways":[0,1]
@@ -105,32 +103,33 @@ var info =
 ,"remotely":[0,2]
 ,"local":[0,1,5,1]
 ,"windows":[0,2,2,2,8,3,10,1]
-,"computer":[0,1]
-,"select":[0,3,2,4,3,1,8,1]
+,"computer":[0,1,1,1]
+,"select":[0,3,1,1,2,4,3,1,8,1]
 ,"start":[0,1,2,3,8,1]
-,"button":[0,1,2,3,3,3,4,5]
+,"button":[0,1,2,3,3,3,4,55]
 ,"browser":[0,1,8,1]
 ,"type":[0,1,2,1]
 ,"servername":[0,1]
-,"address":[0,1,2,6,6,2]
+,"address":[0,1,2,26,6,2]
 ,"port":[0,1,2,8,6,2]
-,"https:\u002F\u002Fservername:6547":[0,1]
-,"https:\u002F\u002Fagentipaddress:6547":[0,1]
+,"https":[0,3]
+,"servername:6547":[0,1]
+,"agentipaddress:6547":[0,1]
 ,"example":[0,1,1,4,2,4,3,1,4,6,5,2]
-,"server":[0,1,2,12,4,1,5,1,6,9,9,1]
+,"server":[0,1,2,32,4,1,5,1,6,9,9,1]
 ,"named":[0,1,2,1]
 ,"comp1":[0,1]
-,"enter":[0,1,1,1,2,1,4,1,5,2,8,1]
-,"https:\u002F\u002Fcomp1:6547":[0,1]
+,"enter":[0,1,1,1,2,1,4,1,5,2,8,2]
+,"comp1:6547":[0,1]
 ,"forgotten":[0,1,8,1]
-,"username":[0,3,2,3,8,7]
-,"password":[0,3,2,3,8,7]
+,"username":[0,3,2,3,8,8]
+,"password":[0,4,2,4,8,8]
 ,"created":[0,1,8,1]
-,"during":[0,1,2,4,3,1,4,1,8,5,10,1]
-,"reset":[0,1,4,1,8,1]
-,"credentials":[0,1,2,1,8,7]
-,"configuration":[0,1,1,1,2,12,3,24,4,2,8,3,10,2]
-,"file":[0,1,2,22,3,3,4,7,8,15,10,11]
+,"during":[0,1,1,1,2,4,3,1,4,1,8,5,10,1]
+,"reset":[0,1,4,11,8,1]
+,"credentials":[0,1,2,1,8,9]
+,"configuration":[0,1,1,1,2,102,3,44,4,2,8,3,10,2]
+,"file":[0,1,2,42,3,24,4,7,8,15,10,11]
 ,"resetting":[0,1,8,1]
 ,"account":[0,1,2,1]
 ,"lock-out":[0,1]
@@ -141,23 +140,21 @@ var info =
 ,"unsuccessful":[0,1,2,1]
 ,"login":[0,1,2,2]
 ,"attempts":[0,1,2,1]
-,"(incorrect":[0,1,2,1]
-,"and\u002For":[0,1,2,1]
-,"password)":[0,1,2,1]
+,"incorrect":[0,1,2,2]
 ,"prevent":[0,1,2,1]
 ,"brute":[0,1,2,1]
 ,"force":[0,1,2,1]
 ,"cracking":[0,1,2,1]
 ,"changing":[0,1,2,1,3,1]
 ,"language":[0,4]
-,"(ui)":[0,1]
 ,"languages":[0,1]
 ,"english":[0,1]
 ,"chinese":[0,1]
 ,"french":[0,1]
 ,"german":[0,1]
 ,"italian":[0,1]
-,"brazilian-portuguese":[0,1]
+,"brazilian":[0,1]
+,"portuguese":[0,1]
 ,"spanish":[0,1]
 ,"change":[0,1,2,1,3,1,5,4,8,1]
 ,"display":[0,1,1,3,2,3,3,2,4,2,5,1,6,1]
@@ -165,147 +162,161 @@ var info =
 ,"selector":[0,1]
 ,"top-right":[0,1]
 ,"corner":[0,1]
-,"drop-down":[0,1,1,2,8,2]
+,"drop-down":[0,1,1,1,8,2]
 ,"list":[0,1,2,1,4,1]
-,"device":[1,5,2,1]
-,"name":[1,2,2,6,6,7]
+,"name":[1,12,2,16,6,7]
+,"device":[1,175,2,1]
+,"status":[1,433,2,1]
+,"option":[1,31,3,26]
+,"line":[1,24,2,3,3,1,4,12]
+,"initializing":[1,21]
+,"low":[1,34,2,29,3,17,4,1]
+,"discharged":[1,22,2,13,3,1]
+,"replace":[1,22,2,1,5,1,8,3]
+,"batteries":[1,24,2,1]
+,"attached":[1,22,5,1]
+,"overloaded":[1,21,2,1]
+,"avr":[1,46,2,58]
+,"boosts":[1,10]
+,"active":[1,42,2,22]
+,"boost":[1,13,2,29]
+,"trim":[1,23,2,29]
+,"performing":[1,22]
+,"self":[1,29,2,8,4,1]
+,"test":[1,118,2,13,4,1]
+,"unknown":[1,34]
+,"communication":[1,22,2,37,6,2]
+,"lost":[1,23,2,24]
+,"load":[1,32,2,29,4,16]
+,"field":[1,170,2,30,3,23,4,72,5,3,8,2]
+,"runtime":[1,28,2,29,3,9]
+,"remaining":[1,25,2,4,3,1]
+,"charge":[1,25,4,12]
+,"voltage":[1,57,2,24,4,24]
+,"screen":[1,49,2,26,3,29,4,38,5,4]
+,"date":[1,12,2,1,4,4,5,13,6,4]
+,"part":[1,12,8,1,9,1]
+,"number":[1,13,2,3,3,2,6,5,8,1]
+,"diagnostics":[1,25,2,1]
+,"self-test":[1,10,2,30]
+,"tests":[1,11]
+,"alarm":[1,36]
+,"nitiate":[1,10]
+,"section":[1,13,2,11,3,1,8,1,10,1]
+,"progress":[1,11,2,11]
+,"passed":[1,12,2,12,4,1]
+,"failed":[1,11,2,21]
+,"refused":[1,12]
+,"aborted":[1,11]
+,"settings":[1,37,2,22,3,7,4,12,5,2,8,2]
+,"high":[1,12,2,9]
+,"transfer":[1,22,2,4]
+,"quality":[1,20,2,11]
+,"sensitivity":[1,24,2,4]
+,"output":[1,14,2,24,4,2]
+,"threshold":[1,13,2,32,3,11]
+,"audible":[1,14]
 ,"displays":[1,5,3,1,5,1]
 ,"top":[1,2,4,1]
 ,"level":[1,1]
 ,"menu":[1,2]
-,"e.g":[1,1,4,1,6,1]
+,"e.g":[1,1,2,2,4,1,6,1,8,1]
 ,"650m1":[1,1,6,1]
 ,"relate":[1,1]
-,"status":[1,23,2,1]
-,"screen":[1,9,2,6,3,9,4,8,5,4]
 ,"sections":[1,2,3,1]
 ,"collapsible":[1,1]
 ,"expandable":[1,1]
 ,"clicking":[1,2,4,1]
 ,"icon":[1,1,2,3,5,2]
 ,"left":[1,1]
-,"section":[1,3,2,1,3,1,8,1,10,1]
-,"field":[1,9,3,3,4,2,5,3,8,2]
 ,"indicates":[1,2,2,1,3,1]
 ,"present":[1,7,2,1]
 ,"states":[1,2,2,1]
 ,"listed":[1,1,3,1,8,1]
 ,"table":[1,1,3,1,4,1,5,1]
 ,"below":[1,4,2,3,3,5,8,1]
-,"note":[1,5,2,1,3,2,6,1,8,1]
+,"note":[1,5,2,1,3,3,6,1,8,1]
 ,"possible":[1,6,4,1]
 ,"depend":[1,1,2,1]
-,"description":[1,8,2,4,4,2,6,3]
-,"line":[1,3,2,3,3,1,4,2]
+,"description":[1,9,2,4,4,2,6,3]
 ,"running":[1,1,2,1,6,4]
 ,"normally":[1,1]
 ,"utility":[1,2,2,1]
-,"initializing":[1,1]
 ,"attempting":[1,1]
 ,"establish":[1,1]
 ,"communications":[1,3,2,4]
 ,"provide":[1,1,10,1]
-,"output":[1,4,2,4,4,2]
-,"load":[1,12,2,9,4,6]
-,"low":[1,4,2,19,3,7,4,1]
-,"runtime":[1,8,2,19,3,9]
-,"remaining":[1,5,2,4,3,1]
 ,"reported":[1,4,2,4,5,1]
 ,"less":[1,2,2,12]
 ,"limit":[1,3,2,2,3,2]
 ,"value":[1,7,2,3,3,2,4,10,5,1,6,1]
-,"settings":[1,6,2,12,3,7,4,2,5,1,6,1,8,2]
 ,"default":[1,1,2,5,4,1,5,3,8,5,9,2,10,1]
 ,"begins":[1,2,8,1]
-,"discharged":[1,2,2,3,3,1]
 ,"outage":[1,2,2,5,3,9]
-,"immediately":[1,1,2,1,3,3]
+,"immediately":[1,1,2,1,3,13]
 ,"process":[1,1,8,2]
 ,"gracefully":[1,1,2,4]
 ,"shutting":[1,1]
 ,"down":[1,1,2,1,3,4]
-,"charge":[1,5,4,2]
 ,"displaying":[1,1]
 ,"100":[1,1]
 ,"happen":[1,1]
 ,"falls":[1,1,3,3]
-,"replace":[1,2,2,1,5,1,8,3]
 ,"reached":[1,1,2,2]
 ,"end":[1,1]
 ,"life":[1,1]
-,"batteries":[1,4,2,1]
-,"attached":[1,2,5,1]
 ,"cannot":[1,3,2,4,4,1,5,2,8,2,9,1]
 ,"detect":[1,1]
-,"overloaded":[1,1,2,1]
-,"support":[1,8,2,6,10,1]
+,"support":[1,9,2,9,10,1]
 ,"current":[1,1,2,1]
 ,"unplug":[1,1]
 ,"equipment":[1,1,2,5,4,1,5,1]
 ,"reduce":[1,1]
-,"overload":[1,1,2,9]
+,"overload":[1,1,2,29]
 ,"services":[1,1,2,5,9,1]
-,"www.apc.com\u002Fsupport":[1,1,2,3]
-,"avr":[1,6,2,18]
-,"boost":[1,3,2,9]
-,"active":[1,2,2,2]
-,"(automatic":[1,1]
-,"voltage":[1,16,2,24,4,4]
-,"regulator)":[1,1]
+,"www.se.com":[1,1,2,3]
+,"automatic":[1,1]
+,"regulator":[1,1]
 ,"correct":[1,3,2,5]
-,"input":[1,5,2,22,4,1,5,1]
+,"input":[1,5,2,22,4,11,5,1]
 ,"without":[1,2]
 ,"switching":[1,2]
-,"trim":[1,3,2,9]
-,"high":[1,2,2,9]
-,"performing":[1,2]
-,"self":[1,9,2,8,4,1]
-,"test":[1,16,2,13,4,1]
-,"diagnostics":[1,6,2,1]
-,"unknown":[1,4]
-,"communication":[1,2,2,7,6,2]
-,"lost":[1,3,2,4]
 ,"sure":[1,1,2,3]
 ,"cable":[1,1,2,2]
 ,"securely":[1,1]
 ,"ends":[1,1]
 ,"turned":[1,1]
 ,"reports":[1,4]
-,"watts":[1,1,4,5]
+,"watts":[1,1,4,7]
 ,"supplied":[1,1]
-,"percentage":[1,4,2,1,4,2]
+,"percentage":[1,4,2,1,4,3]
 ,"full":[1,1]
 ,"rating":[1,3]
 ,"amount":[1,2]
-,"time":[1,2,2,4,3,8,4,9,5,2,8,1,9,1]
+,"time":[1,4,2,14,3,28,4,9,5,2,8,1,9,1]
 ,"shown":[1,2]
 ,"total":[1,2,2,2,5,2]
 ,"capacity":[1,2,2,1,4,1]
-,"view":[1,1,2,2,4,5,8,1]
+,"view":[1,1,2,2,4,25,8,1]
 ,"lists":[1,1,2,2,4,1]
-,"fields":[1,1,2,2,3,1,4,2]
+,"fields":[1,1,2,2,3,1,4,12]
 ,"described":[1,1,2,1]
 ,"every":[1,1]
 ,"values":[1,3,4,2,5,2]
 ,"normal":[1,1,2,4]
-,"(as":[1,1]
 ,"distinct":[1,1]
-,"power)":[1,1]
 ,"volts":[1,1,4,1]
 ,"replacement":[1,3]
-,"date":[1,2,2,1,4,4,5,12,6,4]
-,"installed":[1,1,2,1,6,1,8,2,10,1]
+,"installed":[1,1,2,11,4,2,6,1,8,2,10,1]
 ,"derived":[1,1]
 ,"itself":[1,1,2,1]
 ,"month":[1,1,4,2]
 ,"year":[1,1]
-,"part":[1,2,8,1,9,1]
-,"number":[1,3,2,3,3,2,6,5,8,1]
 ,"essential":[1,1]
 ,"re-ordering":[1,1]
 ,"re-order":[1,2]
 ,"link":[1,2]
-,"page":[1,2,2,1,3,1,6,1,9,1]
+,"page":[1,2,2,1,3,1,9,1]
 ,"buy":[1,1]
 ,"new":[1,1,2,1,4,1,5,1,8,5,9,1]
 ,"online":[1,1]
@@ -313,96 +324,82 @@ var info =
 ,"last":[1,1,2,5]
 ,"results":[1,1]
 ,"enables":[1,1,3,1,4,1,5,1,8,1,9,1]
-,"initiate":[1,4]
-,"tests":[1,2]
+,"initiate":[1,3]
 ,"internal":[1,1,2,1]
 ,"performed":[1,1,5,1]
 ,"restore":[1,1]
-,"run":[1,2,2,2,3,2]
-,"alarm":[1,10]
-,"(using":[1,1]
-,"box":[1,2,3,1,4,1,8,2]
-,"section)":[1,1]
-,".you":[1,1]
+,"run":[1,2,2,2,3,12]
 ,"immediate":[1,1,2,1,3,1]
-,"testa":[1,1]
-,"calibration":[1,3]
 ,"selecting":[1,1,2,2,3,1]
-,"option":[1,1,3,6]
+,"box":[1,2,2,10,3,1,4,11,8,2]
 ,"apply":[1,1,2,2,3,3,8,2]
-,"progress":[1,1,2,1]
 ,"ongoing":[1,1]
-,"passed":[1,2,2,2,4,1]
 ,"relevant":[1,1]
-,"failed":[1,1,2,1]
 ,"succeed":[1,1]
-,"refused":[1,2]
-,"aborted":[1,1]
-,"testcould":[1,1]
 ,"completion":[1,1]
 ,"something":[1,1]
-,"stopped":[1,1,2,2]
+,"stopped":[1,1,2,12]
 ,"canceled":[1,1]
 ,"caused":[1,1,2,1]
 ,"issue":[1,1,10,2]
 ,"thresholds":[1,1]
 ,"explained":[1,2]
-,"displayed":[1,2,3,2,4,3,5,1]
-,"transfer":[1,2,2,4]
+,"displayed":[1,2,3,2,4,3,5,2]
 ,"bypass":[1,2]
 ,"highest":[1,2,2,2]
 ,"supply":[1,2]
 ,"higher":[1,1]
 ,"lowest":[1,1,2,2]
 ,"lower":[1,1,8,1]
-,"sensitivity":[1,2,2,4]
-,"distortions":[1,1]
+,"distortions":[1,2]
 ,"general":[1,1,8,1]
-,"audible":[1,2]
-,"enable":[1,1,2,5,3,1,9,1]
-,"disable":[1,1,2,1]
+,"maximum":[1,1,2,2,8,1]
+,"1500":[1,2]
+,"preferred":[1,1]
+,"used":[1,1,2,8,4,5,5,4,6,1,8,6,9,1]
+,"consumes":[1,1]
+,"1050":[1,1]
+,"exceeded":[1,1,2,24,3,11]
+,"generated":[1,1,3,3]
+,"enable":[1,1,2,5,3,1,4,10,9,1]
+,"disable":[1,5,2,1]
 ,"sounds":[1,1]
-,"response":[1,1,2,1,3,1]
+,"response":[1,2,2,1,3,1]
 ,"problems":[1,1]
 ,"right":[1,1,2,1]
 ,"icons":[1,1]
-,"enabled":[1,1,2,9]
+,"enabled":[1,1,2,29]
 ,"disabled":[1,1,2,1,4,2]
-,"threshold":[1,3,2,12,3,1]
-,"maximum":[1,1,2,2,8,1]
-,"1500":[1,1]
-,"preferred":[1,1]
-,"used":[1,1,2,8,4,5,5,4,6,1,8,6,9,1]
-,"(%)":[1,1,4,2]
-,"consumes":[1,1]
-,"1050":[1,1]
-,"(70":[1,1]
-,"1500)":[1,1]
-,"exceeded":[1,1,2,4,3,1]
-,"generated":[1,1,3,3]
+,"day":[1,1]
+,"range":[1,1,2,11]
+,"specified":[1,1]
+,"sound":[1,1]
+,"hiberating":[1,1]
+,"check":[1,1,2,13,3,1,4,10,8,1,9,1]
+,"hibernation":[1,1]
+,"mode":[1,1]
 ,"occur":[2,2]
 ,"separates":[2,1]
 ,"categories":[2,2]
-,"-critical":[2,1]
-,"(severe)":[2,2]
-,"warning":[2,5,3,4,4,2]
-,"informational":[2,7,4,2]
+,"severe":[2,2]
+,"warning":[2,15,3,4,4,2]
+,"informational":[2,17,4,2]
 ,"event\u0027s":[2,1]
 ,"category":[2,1]
 ,"hidden":[2,1,4,1]
 ,"beside":[2,1]
-,"-sign":[2,1]
-,"hide":[2,1,4,2]
+,"sign":[2,1,8,2]
+,"hide":[2,1,4,13]
 ,"cause":[2,3,3,2,5,1]
 ,"certain":[2,2,9,1]
 ,"actions":[2,2]
 ,"separate":[2,1]
-,"columns":[2,1,4,4]
-,"logging":[2,2,4,4]
+,"columns":[2,1,4,24]
+,"logging":[2,22,4,14]
 ,"records":[2,1,4,2]
 ,"checkbox":[2,9,3,4,4,1,9,3]
 ,"selected":[2,7,3,7,5,1,9,1]
-,"e-mail":[2,40]
+,"e-mail":[2,151]
 ,"sends":[2,1,9,1]
 ,"message":[2,1]
 ,"users":[2,3]
@@ -411,13 +408,13 @@ var info =
 ,"initiates":[2,1,3,2]
 ,"sequence":[2,3,3,1]
 ,"important":[2,2]
-,"command":[2,19,3,4]
+,"command":[2,49,3,24]
 ,"direct":[2,1]
 ,"effect":[2,1]
 ,"specify":[2,3]
 ,"runs":[2,1]
 ,"user-specified":[2,1]
-,"files":[2,1,4,3,8,2,10,4]
+,"files":[2,13,4,25,8,5,10,5]
 ,"often":[2,1,4,1]
 ,"shut":[2,1,3,4]
 ,"open":[2,3,8,1]
@@ -425,17 +422,14 @@ var info =
 ,"order":[2,2,3,1]
 ,"avoid":[2,1]
 ,"loss":[2,1]
-,"data":[2,2,4,14,5,1,9,1]
+,"data":[2,2,4,64,5,1,9,1]
 ,"placed":[2,1]
-,"folder":[2,2,8,1]
-,"<installation":[2,1]
-,"folder>\u005Capc\u005Cpowerchute":[2,1]
-,"shutdown\u005Cagent\u005Ccmdfiles":[2,2]
-,"c:\u005Cprogram":[2,2,4,2,8,3,10,1]
-,"files\u005Capc\u005Cpowerchute":[2,2,4,2,8,3,10,1]
+,"folder":[2,3,8,1]
+,"apc":[2,3,4,2,8,4,10,1]
+,"cmdfiles":[2,2]
+,"program":[2,2,4,2,8,3,9,4,10,1]
 ,"choose":[2,1,3,1,4,3]
-,"duration":[2,5,3,1]
-,"check":[2,3,3,1,8,1,9,1]
+,"duration":[2,15,3,11]
 ,"contents":[2,2,4,1]
 ,"executing":[2,1]
 ,"color":[2,1]
@@ -458,7 +452,6 @@ var info =
 ,"lose":[2,1]
 ,"proper":[2,2]
 ,"correctly":[2,2]
-,"-the":[2,3]
 ,"alert":[2,1]
 ,"situations":[2,1]
 ,"monitored":[2,1]
@@ -466,13 +459,11 @@ var info =
 ,"operation":[2,2,3,1]
 ,"due":[2,1]
 ,"poor":[2,1]
-,"quality":[2,11]
 ,"begin":[2,1]
 ,"105":[2,1]
-,"(this":[2,2]
 ,"varies":[2,1]
 ,"110":[2,1]
-,"adding":[2,2]
+,"adding":[2,12]
 ,"clears":[2,1]
 ,"persists":[2,1]
 ,"disconnect":[2,1]
@@ -484,16 +475,16 @@ var info =
 ,"determine":[2,1]
 ,"causes":[2,1,3,2]
 ,"exists":[2,1]
-,"needs":[2,8]
+,"needs":[2,18]
 ,"repaired":[2,1]
-,"replaced":[2,3]
+,"replaced":[2,13]
 ,"further":[2,1,3,1]
 ,"pass":[2,1]
 ,"bad":[2,1]
 ,"reporting":[2,1,5,3]
-,"insufficient":[2,3]
+,"insufficient":[2,13]
 ,"condition":[2,7]
-,"clear":[2,2,3,1,4,3]
+,"clear":[2,2,3,1,4,23]
 ,"again":[2,2]
 ,"fails":[2,1]
 ,"breached":[2,1]
@@ -513,10 +504,10 @@ var info =
 ,"forced":[2,2]
 ,"enough":[2,3]
 ,"perform":[2,3]
-,"replacing":[2,1]
+,"replacing":[2,11]
 ,"need":[2,1]
 ,"began":[2,2]
-,"disconnected":[2,3]
+,"disconnected":[2,13]
 ,"removed":[2,1]
 ,"frequent":[2,2]
 ,"overvoltage":[2,2]
@@ -536,8 +527,6 @@ var info =
 ,"returns":[2,4]
 ,"becomes":[2,4,5,1]
 ,"decreased":[2,2]
-,"(on":[2,4]
-,"event)":[2,4]
 ,"accept":[2,6]
 ,"sensitive":[2,4]
 ,"frequently":[2,4]
@@ -549,37 +538,36 @@ var info =
 ,"continuously":[2,2]
 ,"least":[2,2]
 ,"hour":[2,2,5,4]
-,"contact":[2,5,6,2,10,1]
-,"apc":[2,2,8,1]
+,"contact":[2,15,6,2,10,1]
+,"schneider":[2,2,5,1,9,1]
+,"electric":[2,2,5,1,9,1]
 ,"improve":[2,2,9,1]
 ,"invalid":[2,3,8,1]
 ,"pcssconfig.ini":[2,3,8,11,10,1]
 ,"text":[2,1,4,2,8,2]
 ,"editor":[2,1,8,1]
-,"(e.g":[2,2,8,1]
-,"notepad)":[2,1,8,1]
+,"notepad":[2,1,8,1]
 ,"errors":[2,2]
 ,"unsuccessfully":[2,1]
 ,"attempted":[2,1]
 ,"report":[2,1,5,5]
-,"longer":[2,6]
-,"restored":[2,1]
+,"longer":[2,26]
+,"restored":[2,11]
 ,"follows":[2,4]
-,"solved":[2,1]
+,"solved":[2,11]
 ,"corrected":[2,2]
-,"range":[2,1]
 ,"out-of-range":[2,1]
-,"starting":[2,3,3,1,4,1,8,1]
+,"starting":[2,13,3,11,4,1,8,1]
 ,"various":[2,2]
 ,"stages":[2,1]
 ,"procedure":[2,1]
-,"established":[2,2]
-,"monitoring":[2,3,4,1]
-,"started":[2,3,4,1]
+,"established":[2,12]
+,"monitoring":[2,23,4,1]
+,"started":[2,13,4,1]
 ,"sufficient":[2,1]
-,"initiated":[2,1,3,1]
+,"initiated":[2,11,3,1]
 ,"details":[2,1]
-,"reconnected":[2,2]
+,"reconnected":[2,12]
 ,"previously":[2,1]
 ,"relating":[2,1,4,1]
 ,"changed":[2,1,3,1]
@@ -590,15 +578,15 @@ var info =
 ,"session":[2,2]
 ,"expired":[2,1]
 ,"inactivity":[2,1]
-,"durations":[2,2,3,2]
-,"shutdowns":[2,1,3,1]
+,"durations":[2,2,3,12]
+,"shutdowns":[2,11,3,1]
 ,"longest":[2,2]
 ,"associated":[2,1]
 ,"impact":[2,1]
 ,"expand":[2,1]
 ,"summary":[2,1,3,3]
 ,"delay":[2,1]
-,"execution":[2,1,3,1]
+,"execution":[2,1,3,11]
 ,"addresses":[2,2]
 ,"notified":[2,1]
 ,"receive":[2,2]
@@ -609,16 +597,13 @@ var info =
 ,"messages":[2,2]
 ,"includes":[2,1,3,1,4,1,5,1]
 ,"pagers":[2,1]
-,"e-mail)":[2,1]
-,"smtp":[2,7]
-,"(hostname":[2,2]
-,"ipv4":[2,3]
-,"ipv6)":[2,2]
+,"smtp":[2,27]
+,"hostname":[2,23]
+,"ipv4":[2,23]
+,"ipv6":[2,23]
 ,"identifies":[2,1]
 ,"methods":[2,1]
 ,"mentioned":[2,1]
-,"ipv6":[2,1]
-,"hostname":[2,1]
 ,"mail.server.com":[2,1]
 ,"specifies":[2,2,4,1]
 ,"recipient":[2,1]
@@ -632,20 +617,19 @@ var info =
 ,"ranging":[2,1]
 ,"5000":[2,1]
 ,"32768":[2,1]
-,"ssl\u002Ftls":[2,3]
+,"ssl":[2,7,8,2]
+,"tls":[2,6]
 ,"defines":[2,1]
 ,"encryption":[2,4]
 ,"protocol":[2,6]
 ,"none":[2,1]
-,"authentication":[2,5,8,2]
+,"authentication":[2,15,8,2]
 ,"unencrypted":[2,1]
 ,"encrypted":[2,3]
 ,"smtps":[2,1]
-,"ssl":[2,4,8,2]
 ,"email":[2,3]
 ,"administrator":[2,4]
 ,"assigned":[2,2,6,1]
-,"tls":[2,3]
 ,"identity":[2,2,9,1]
 ,"verifies":[2,1]
 ,"valid":[2,2,8,1]
@@ -655,18 +639,16 @@ var info =
 ,"risk":[2,1]
 ,"man-in-the-middle":[2,1]
 ,"attacks":[2,1]
-,"recipients":[2,4]
+,"recipients":[2,14]
 ,"pcss.log":[2,1]
 ,"common":[2,1]
 ,"reasons":[2,1]
 ,"received":[2,1]
-,"incorrect":[2,1]
 ,"mismatch":[2,1]
 ,"proxy":[2,1]
 ,"issues":[2,1,10,1]
 ,"unreachable":[2,1]
 ,"chosen":[2,1,3,2,5,1,8,3,10,1]
-,"authenticating":[2,4]
 ,"uses":[2,2,5,1]
 ,"self-signed":[2,1]
 ,"added":[2,1]
@@ -679,16 +661,16 @@ var info =
 ,"apcpbeagent":[2,2]
 ,"copy":[2,1,8,3]
 ,"server.crt":[2,2]
-,"(or":[2,1,4,2]
-,"server.cer)":[2,1]
+,"server.cer":[2,1]
 ,"directory":[2,3,4,1,8,8,10,5]
-,"shutdown\u005Cjre\u005Clib\u005Csecurity)":[2,1]
+,"lib":[2,1]
 ,"prompt":[2,1]
 ,"privileges":[2,1]
 ,"navigate":[2,1,8,3]
 ,"execute":[2,1]
 ,"import":[2,1]
-,".\u005Cbin\u005Ckeytool":[2,1]
+,"bin":[2,1,5,1]
+,"keytool":[2,1]
 ,"-import":[2,1]
 ,"alias":[2,1]
 ,"mailserv":[2,1]
@@ -697,15 +679,15 @@ var info =
 ,"storepass":[2,1]
 ,"changeit":[2,1]
 ,"prompted":[2,1]
-,"removing":[2,1]
-,"add":[2,1,4,1,5,2,8,1]
-,"add\u002Fremove":[2,1]
-,"remove":[2,1]
+,"authenticating":[2,24]
+,"removing":[2,11]
+,"add":[2,22,4,1,5,2,8,1]
+,"remove":[2,22]
 ,"filling":[2,1]
-,"location":[2,3,6,2,8,3,10,1]
+,"location":[2,13,6,2,8,3,10,1]
 ,"optional":[2,2]
 ,"included":[2,1]
-,"e-mails":[2,2]
+,"e-mails":[2,22]
 ,"intended":[2,1]
 ,"represent":[2,1]
 ,"person":[2,1]
@@ -716,7 +698,7 @@ var info =
 ,"advise":[2,1,9,1]
 ,"testing":[2,1]
 ,"create":[2,1,8,1]
-,"basic":[2,1]
+,"basic":[2,11]
 ,"you\u2019re":[2,1]
 ,"going":[2,1,3,1]
 ,"respective":[2,1]
@@ -750,17 +732,14 @@ var info =
 ,"combined":[3,1]
 ,"application":[3,3]
 ,"configurable":[3,2]
-,"(because":[3,1]
 ,"always":[3,2,5,2]
-,"shutdown)":[3,1]
 ,"different":[3,2,5,1,8,1]
 ,"radio":[3,3]
-,"(under":[3,1]
-,"heading)":[3,1]
+,"heading":[3,1,4,1]
 ,"choosing":[3,1,4,1]
 ,"four":[3,1]
-,"(discussed":[3,1]
-,"above)":[3,1]
+,"discussed":[3,1]
+,"above":[3,1,8,1]
 ,"works":[3,1]
 ,"interactively":[3,1]
 ,"checkboxes":[3,1,4,1]
@@ -772,30 +751,26 @@ var info =
 ,"inform":[3,1]
 ,"interaction":[3,1]
 ,".the":[3,1]
-,"*the":[3,1]
 ,"row":[3,1,5,5]
 ,"return":[3,1,4,1]
 ,"upon":[3,1,8,1]
 ,"specific":[3,1]
 ,"usually":[3,1]
 ,"120":[3,1]
-,"required":[3,2]
+,"required":[3,12]
 ,"interacts":[3,1]
 ,"update":[3,1,6,2,8,8,9,2]
-,"(note":[3,1]
-,"file)":[3,1]
+,"failure":[3,40]
 ,"interrupted":[4,1]
 ,"everyday":[4,1]
 ,"occurrences":[4,2]
 ,"classifies":[4,1]
 ,"recent":[4,3]
 ,"starts":[4,1]
-,"export":[4,2]
+,"export":[4,12]
 ,"eventlog.txt":[4,1,10,1]
-,"shutdown\u005Cagent":[4,1,8,2,10,1]
 ,"wherever":[4,2]
-,"installed)":[4,2]
-,"delete":[4,3,5,2,8,1]
+,"delete":[4,13,5,2,8,1]
 ,"bottom":[4,2,5,1]
 ,"refresh":[4,2,8,1]
 ,"first":[4,2,8,1]
@@ -803,28 +778,25 @@ var info =
 ,"stores":[4,1,8,1]
 ,"device\u2019s":[4,2]
 ,"located":[4,1,8,1]
-,"shutdown\u005Cagent\u005Cenergylog":[4,1]
+,"energylog":[4,1,10,1]
 ,"logs":[4,3]
 ,"structure":[4,1]
 ,"2010timestamp":[4,2]
 ,"realload":[4,3]
-,"(watts)":[4,2]
 ,"relativeload":[4,1]
-,"(percentage)":[4,1]
 ,"calculatedload":[4,2]
 ,"368633153;200.0;200.0;200.0":[4,2]
 ,"reading":[4,1]
-,"timestamp":[4,7]
+,"timestamp":[4,7,10,2]
 ,"interpret":[4,1]
 ,"calculate":[4,1,5,1]
 ,"difference":[4,1]
 ,"unix":[4,1]
 ,"point":[4,1]
-,"(01\u002F01\u002F1970)":[4,1]
-,"(01\u002F01\u002F2010)":[4,1]
+,"1970":[4,1]
+,"2010":[4,1]
 ,"1262304000":[4,2]
-,"(for":[4,1]
-,"368633153)":[4,1]
+,"368633153":[4,1]
 ,"equals":[4,3,8,1]
 ,"1,630,937,153":[4,1]
 ,"third-party":[4,1]
@@ -849,8 +821,8 @@ var info =
 ,"dst":[4,1]
 ,"relative":[4,1]
 ,"ago":[4,1]
-,"entries":[4,4]
-,"entry":[4,5]
+,"entries":[4,14]
+,"entry":[4,25]
 ,"captures":[4,1]
 ,"5-minute":[4,1]
 ,"null":[4,3]
@@ -859,39 +831,34 @@ var info =
 ,"200.0":[4,2]
 ,"calculating":[4,1,5,1]
 ,"convert":[4,3]
-,"kilowatt":[4,1]
-,"(kwh)":[4,1]
+,"kilowatt":[4,1,5,1]
+,"kwh":[4,2,5,1]
 ,"divide":[4,2]
 ,"12,000":[4,2]
 ,"0.01666667":[4,1]
-,"kwh":[4,1,5,1]
 ,"formula":[4,1]
 ,"multiply":[4,1]
 ,"300,000":[4,1]
-,"interval":[4,7]
+,"interval":[4,17]
 ,"milliseconds":[4,1]
-,"1000)":[4,2]
+,"1000":[4,3]
 ,"3,600,000,000":[4,1]
 ,"kilowatts":[4,1,5,1]
-,"(3600":[4,1]
-,"1000":[4,1]
+,"3600":[4,1]
 ,"sorted":[4,1]
 ,"appearing":[4,1]
 ,"gives":[4,1,5,1]
 ,"brief":[4,1]
-,"(vac)":[4,1]
+,"vac":[4,11]
 ,"made":[4,1]
-,"(vdc)":[4,1]
+,"vdc":[4,11]
 ,"device\u0027s":[4,1]
-,"recording":[4,4]
-,"show":[4,1,8,1]
-,"\u002Fhide":[4,1]
+,"recording":[4,14]
+,"show":[4,11,8,1]
 ,"affects":[4,1]
 ,"recorded":[4,3]
 ,"dragging":[4,1]
-,"heading":[4,1]
 ,"frequency":[4,1,9,1]
-,"(hz)":[4,1]
 ,"move":[4,1]
 ,"re-arrange":[4,1]
 ,"original":[4,1,5,1]
@@ -902,17 +869,15 @@ var info =
 ,"snapshot":[4,1]
 ,"regular":[4,1]
 ,"intervals":[4,1]
-,"expiration":[4,3]
+,"expiration":[4,34]
 ,"deleting":[4,1,8,1]
 ,"deleted":[4,1,5,2,8,1]
 ,"old":[4,1]
 ,"taking":[4,1]
-,"disk":[4,3]
-,"space":[4,3]
+,"disk":[4,23]
+,"space":[4,23]
 ,"lot":[4,2]
 ,"aware":[4,1]
-,"(event":[4,1]
-,"expiration)":[4,1]
 ,"long":[4,1]
 ,"mean":[4,1]
 ,"eventually":[4,1]
@@ -925,8 +890,6 @@ var info =
 ,"dioxide":[5,3]
 ,"costs":[5,6]
 ,"accesses":[5,1]
-,"schneider":[5,1,9,1]
-,"electric":[5,1,9,1]
 ,"servers":[5,1]
 ,"internet":[5,1]
 ,"consumed":[5,1]
@@ -940,14 +903,12 @@ var info =
 ,"prices":[5,1]
 ,"emissions":[5,3]
 ,"country":[5,4]
-,"(see":[5,1]
-,"settings)":[5,1]
 ,"co2":[5,3]
 ,"emitted":[5,1]
 ,"generating":[5,1]
 ,"measured":[5,1]
 ,"kilograms":[5,1]
-,"pounds":[5,1]
+,"pounds":[5,2]
 ,"greenhouse":[5,1]
 ,"gas":[5,1]
 ,"traps":[5,1]
@@ -963,9 +924,7 @@ var info =
 ,"prior":[5,2]
 ,"today\u2019s":[5,3]
 ,"whereas":[5,1]
-,"(if":[5,1]
 ,"upgrade":[5,1,8,2]
-,"date)":[5,1]
 ,"cumulative":[5,2]
 ,"correspond":[5,1]
 ,"lcd":[5,1]
@@ -983,44 +942,34 @@ var info =
 ,"know":[5,1]
 ,"electricity":[5,1]
 ,"bill":[5,1]
-,"<kilowatt\u002Fpounds>":[5,1]
 ,"plus":[5,1]
 ,"symbol":[5,1]
 ,"foot":[5,1]
 ,"history":[5,1]
 ,"pen":[5,1]
 ,"edit":[5,1,8,1]
-,"bin":[5,1]
 ,"future":[5,1]
 ,"dates":[5,2]
 ,"combine":[5,1]
 ,"generate":[5,1]
 ,"suppose":[5,1]
-,"04\u002F25\u002F2017":[5,1]
+,"2017":[5,4]
 ,"0.1":[5,2]
-,"10\u002F30\u002F2017":[5,2]
 ,"0.15":[5,2]
 ,"let\u2019s":[5,1]
 ,"say":[5,1]
 ,"january":[5,1]
-,"2018":[5,1]
-,"(displayed":[5,1]
-,"01\u002F03\u002F2018)":[5,1]
-,"04\u002F25":[5,1]
-,"10\u002F29":[5,1]
-,"2017":[5,1]
-,"01\u002F03\u002F2018":[5,1]
+,"2018":[5,3]
 ,"dialog":[6,1,8,3,10,1]
 ,"parameter":[6,3]
 ,"firmware":[6,2]
 ,"manufacture":[6,1]
 ,"manufactured":[6,1]
+,"settingspage":[6,1]
 ,"protected":[6,1]
-,"(es)":[6,1]
 ,"product":[6,1,9,1]
 ,"version":[6,6,8,7,9,1]
 ,"called":[8,2]
-,"systemsit":[8,1]
 ,"recommended":[8,2]
 ,"lead":[8,1]
 ,"configurations":[8,1]
@@ -1031,9 +980,6 @@ var info =
 ,"machine":[8,2]
 ,"target":[8,1]
 ,"fa360654":[8,2]
-,"[credentials]":[8,2]
-,"username=password=enter":[8,1]
-,"sign":[8,2]
 ,"128":[8,2]
 ,"characters":[8,3]
 ,"length":[8,2]
@@ -1058,8 +1004,7 @@ var info =
 ,"accordingly":[8,1]
 ,"development":[8,1]
 ,"kit":[8,1]
-,"(jdk)":[8,1]
-,"jdk":[8,3]
+,"jdk":[8,4]
 ,"already":[8,1]
 ,"follow":[8,1]
 ,"download":[8,1,9,1]
@@ -1068,17 +1013,14 @@ var info =
 ,"adoptium":[8,2]
 ,"openjdk":[8,2]
 ,"website":[8,1]
-,"v1.3":[8,1]
+,"v1.4":[8,1]
 ,"ships":[8,1]
 ,"release":[8,1]
 ,"64-bit":[8,1]
 ,"versions":[8,1]
-,"detailed":[8,1]
-,"updates":[8,3,9,4]
-,"shutdown\u005Cupdates":[8,1]
-,"(tar.gz":[8,1]
-,"zip)":[8,1]
-,"above":[8,1]
+,"updates":[8,4,9,4]
+,"tar.gz":[8,1]
+,"zip":[8,1,10,5]
 ,"want":[8,1]
 ,"appear":[8,1]
 ,"asking":[8,1]
@@ -1095,13 +1037,11 @@ var info =
 ,"customer":[9,4,10,2]
 ,"experience":[9,4]
 ,"improvement":[9,4]
-,"program":[9,4]
-,"(ceip)":[9,2]
+,"ceip":[9,7]
 ,"powerchute\u0027s":[9,1]
 ,"helps":[9,1]
 ,"best":[9,1]
 ,"deploy":[9,1]
-,"ceip":[9,5]
 ,"collect":[9,1]
 ,"environment":[9,2]
 ,"completely":[9,1]
@@ -1122,17 +1062,15 @@ var info =
 ,"opt-out":[9,1]
 ,"checking":[9,1]
 ,"troubleshooting":[10,3]
-,"zip":[10,5]
 ,"archive":[10,5]
 ,"help":[10,2]
 ,"team":[10,2]
 ,"creates":[10,1]
 ,"necessary":[10,1]
 ,"saved":[10,1]
-,"pcssfiles-<timestamp>":[10,2]
+,"pcssfiles-":[10,2]
 ,".zip":[10,2]
 ,"exported":[10,1]
-,"energylog":[10,1]
 ,"datalog":[10,1]
 ,"eventlog_eng.txt":[10,1]
 ,"cmdfile.log":[10,1]
@@ -1143,6 +1081,9 @@ var info =
 ,"data.dat":[10,1]
 ,"regional":[10,1]
 ,"technical":[10,1]
+},
+"synonyms":
+{
 }
 }
 ;Search.control.advance(info);
